@@ -34,14 +34,14 @@ def parse_int_rangelist(s, sorted=False):
             if match:
                 start = int(match.group(1))
                 end = int(match.group(2))
-                for i in xrange(start, end+1):
+                for i in range(start, end+1):
                     retval.append(i)
             else:
                 try:
                     x = int(t)
                     retval.append(x)
                 except ValueError:
-                    print "Error: Can not parse token '%s' from range list '%s'" % (t, s)
+                    print("Error: Can not parse token '%s' from range list '%s'" % (t, s))
 
     if sorted:
         retval.sort()
